==> haskell-criterion-measurement-0.1.3.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 criterion-measurement
version:              0.1.3.0
visibility:           public
id:                   criterion-measurement-0.1.3.0-1tPw8wyPLPfDMqCRf9Ihl8
key:                  criterion-measurement-0.1.3.0-1tPw8wyPLPfDMqCRf9Ihl8
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:
    Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/criterion
synopsis:             Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.

category:             Development, Performance, Testing, Benchmarking
abi:                  01ddb27cfc1279d684a9d86feda50582
exposed:              True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal

import-dirs:          /usr/lib/ghc-9.0.1/site-local/criterion-measurement-0.1.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/criterion-measurement-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/criterion-measurement-0.1.3.0

hs-libraries:         HScriterion-measurement-0.1.3.0-1tPw8wyPLPfDMqCRf9Ihl8
depends:
    aeson-1.5.6.0-nrMp0b6teF7D3JqNhCf9o base-4.15.0.0
    base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC binary-0.8.8.0
    containers-0.6.4.1 deepseq-1.4.5.0
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG

haddock-interfaces:
    /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock

haddock-html:         /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-measurement-0.1.3.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 criterion-measurement
version:              0.1.3.0
visibility:           public
id:                   criterion-measurement-0.1.3.0-5UUksa6gIHVHXLNCpHYUTn
key:                  criterion-measurement-0.1.3.0-5UUksa6gIHVHXLNCpHYUTn
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:
    Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/criterion
synopsis:             Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.

category:             Development, Performance, Testing, Benchmarking
abi:                  9f7e39c17c2c89b22338f7ced929883a
exposed:              True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal

import-dirs:          /usr/lib/ghc-9.0.1/site-local/criterion-measurement-0.1.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/criterion-measurement-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/criterion-measurement-0.1.3.0

hs-libraries:         HScriterion-measurement-0.1.3.0-5UUksa6gIHVHXLNCpHYUTn
depends:
    aeson-1.5.6.0-FH3TyhjfoU9J1nOiG0i6k4 base-4.15.0.0
    base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC binary-0.8.8.0
    containers-0.6.4.1 deepseq-1.4.5.0
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG

haddock-interfaces:
    /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock

haddock-html:         /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
